@@ -988,6 +988,10 @@ def run_transform(run_options, **kwargs):
         parent_run_id = run_options.pop('parent_run_id')
     else:
         parent_run_id = None
+    if ('last_in_chain_of_xforms' in run_options):
+        last_in_chain_of_xforms = run_options.pop('last_in_chain_of_xforms')
+    else:
+        last_in_chain_of_xforms = 'False'
     input_data_spec = run_options.pop('input_data_spec')
     xformname = run_options.pop('xformname')
     found, run_id = check_in_cache(input_data_spec, xformname)
@@ -1010,8 +1014,7 @@ def run_transform(run_options, **kwargs):
     elif (run_location == "singlevm"):
         instance_type = run_options.pop('instance_type')
         return run_transform_singlevm(service_name, parent_run_id,
-                run_options['last_in_chain_of_xforms'],
-                input_data_spec, xformname, instance_type, **kwargs)
+                last_in_chain_of_xforms, input_data_spec, xformname, instance_type, **kwargs)
     elif (run_location == "emr"):
         time_spec = run_options.pop('time_spec')
         service_name = run_options.pop('service_name')
